antiSMASH object model
======================

|Build Status|

An object model for mapping antiSMASH data objects from and to Redis via
aioredis.

License
-------

| Under the same GNU AGPL v3 or later license as the rest of antiSMASH.
| See ```LICENSE.txt`` <LICENSE.txt>`__ for details.

.. |Build Status| image:: https://github.drone.secondarymetabolites.org/api/badges/antismash/models/status.svg
   :target: https://github.drone.secondarymetabolites.org/antismash/models
